/*******************************************************************************
 * Copyright (C) 2005-2012 Alfresco Software Limited.
 * 
 * This file is part of the Alfresco Mobile SDK.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *  
 *  http://www.apache.org/licenses/LICENSE-2.0
 * 
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 ******************************************************************************/
package org.alfresco.mobile.android.api.model;

/**
 * Enumeration Constants that represents the data types a property can be.
 * 
 * @author Jean Marie Pascal
 */
public enum PropertyType
{

    STRING("String"), ID("Id"), INTEGER("Integer"), DECIMAL("Decimal"), DATETIME("DateTime"), BOOLEAN("Boolean");

    /** The value associated to an enum. */
    private final String value;

    /**
     * Instantiates a new property type.
     * 
     * @param v the value of the enum.
     */
    PropertyType(String v)
    {
        value = v;
    }

    /**
     * Value.
     * 
     * @return the string
     */
    public String value()
    {
        return value;
    }

    /**
     * From value.
     * 
     * @param v the value of the enum.
     * @return the property type
     */
    public static PropertyType fromValue(String v)
    {
        for (PropertyType c : PropertyType.values())
        {
            if (c.value.equalsIgnoreCase(v)) { return c; }
        }
        throw new IllegalArgumentException(v);
    }
}